@@ -35,6 +35,11 @@
  * -don't call get_lda_err from failed OraLogon, may not have good lda
  * -change way cur handles are made, don't use argv[1] anymore
  *-----------------------------------------------------------------------------
+ * Version 2.11 April, 1994
+ * Tom Poindexter, Boulder Colorado
+ * tpoind@advtech.uswest.com  or tpoindex@nyx.cs.du.edu   
+ * -don't call parse_columns after orsql DDL or DCL, caused error in V7 
+ *-----------------------------------------------------------------------------
  *
  */
 
@@ -1291,26 +1296,41 @@ Tcl_OraSql (clientData, interp, argc, argv)
     OraCurs[hand].row_num    = 0;
     OraCurs[hand].fetch_end  = 1;
     OraCurs[hand].fetch_cnt  = 0;
+  
+    /* only call parse_columns after DML (insert,select,update,delete) */
+    if (OraCurs[hand].cda->ft == 3 || OraCurs[hand].cda->ft == 4 ||
+        OraCurs[hand].cda->ft == 5 || OraCurs[hand].cda->ft == 9) {
 
-    if (parse_columns(interp, hand) != -1) {
-
-        oexec(OraCurs[hand].cda);
-
-        /* set msg array variable "rows" to rpc (rows processed count) */
-        /* in case of insert, update, delete,                          */
-        sprintf(buf,"%d",OraCurs[hand].cda->rpc);
-        Tcl_SetVar2(interp, OraMsgArray, "rows", buf, TCL_GLOBAL_ONLY);
-
-	/* cause first orafetch to fetch */
-	OraCurs[hand].row_num   = OraCurs[hand].cache_size;
-	OraCurs[hand].fetch_end = 0;        /* try to fetch */
-	OraCurs[hand].fetch_cnt = 0;        /* start fetch cnt at zero */
+      if (parse_columns(interp, hand) != -1) {
+  
+          oexec(OraCurs[hand].cda);
+  
+          /* set msg array variable "rows" to rpc (rows processed count) */
+          /* in case of insert, update, delete,                          */
+          sprintf(buf,"%d",OraCurs[hand].cda->rpc);
+          Tcl_SetVar2(interp, OraMsgArray, "rows", buf, TCL_GLOBAL_ONLY);
+  
+  	/* cause first orafetch to fetch */
+  	OraCurs[hand].row_num   = OraCurs[hand].cache_size;
+  	OraCurs[hand].fetch_end = 0;        /* try to fetch */
+  	OraCurs[hand].fetch_cnt = 0;        /* start fetch cnt at zero */
+  
+      } else {
+  	get_ora_err(interp,hand);
+  	Tcl_AppendResult (interp, argv[0], ": parse_columns failed ", 
+  			  (char *) NULL);
+  	return TCL_ERROR;
+      }
 
     } else {
-	get_ora_err(interp,hand);
-	Tcl_AppendResult (interp, argv[0], ": parse_columns failed ", 
-			  (char *) NULL);
-	return TCL_ERROR;
+      oexec(OraCurs[hand].cda);
+      if (OraCurs[hand].cda->rc != 0) {
+  	get_ora_err(interp,hand);
+  	Tcl_AppendResult (interp, argv[0], ": oexec of DDL failed ",
+  			  (char *) NULL);
+  	return TCL_ERROR;
+      }
+
     }
 
     get_ora_err(interp,hand);
